@@ -11,6 +11,8 @@ Example:
     ./launch_tor_with_simplehttpd.py -p 8080 -d /opt/files/
 '''
 
+from __future__ import print_function
+
 import SimpleHTTPServer
 import SocketServer
 import functools
@@ -26,23 +28,23 @@ import txtorcon
 
 
 def print_help():
-    print __doc__
+    print(__doc__)
 
 
 def print_tor_updates(prog, tag, summary):
     # Prints some status messages while booting tor
-    print 'Tor booting [%d%%]: %s' % (prog, summary)
+    print('Tor booting [%d%%]: %s' % (prog, summary))
 
 
 def start_httpd(httpd):
     # Create a new thread to serve requests
-    print 'Starting httpd...'
+    print('Starting httpd...')
     return thread.start_new_thread(httpd.serve_forever, ())
 
 
 def stop_httpd(httpd):
     # Kill the httpd
-    print 'Stopping httpd...'
+    print('Stopping httpd...')
     httpd.shutdown()
 
 
@@ -51,16 +53,16 @@ def setup_complete(config, port, proto):
     # We create a reference to this function via functools.partial that
     # provides us with a reference to 'config' and 'port', twisted then adds
     # the 'proto' argument
-    print '\nTor is now running. The hidden service is available at'
-    print '\n\thttp://%s:%i\n' % (config.HiddenServices[0].hostname, port)
+    print('\nTor is now running. The hidden service is available at')
+    print('\n\thttp://%s:%i\n' % (config.HiddenServices[0].hostname, port))
     # This is probably more secure than any other httpd...
-    print '### DO NOT RELY ON THIS SERVER TO TRANSFER FILES IN A SECURE WAY ###'
+    print('## DO NOT RELY ON THIS SERVER TO TRANSFER FILES IN A SECURE WAY ##')
 
 
 def setup_failed(arg):
     # Callback from twisted if tor could not boot. Nothing to see here, move
     # along.
-    print 'Failed to launch tor', arg
+    print('Failed to launch tor', arg)
     reactor.stop()
 
 
@@ -69,12 +71,12 @@ def main():
     try:
         opts, args = getopt.getopt(sys.argv[1:], 'hd:p:')
     except getopt.GetoptError as excp:
-        print str(excp)
+        print(str(excp))
         print_help()
         return 1
 
     serve_directory = '.'  # The default directory to serve files from
-    hs_public_port = 8011  # The default port the hidden service is available on
+    hs_public_port = 8011  # The port the hidden service is available on
     web_port = 4711  # The real server's local port
     web_host = '127.0.0.1'  # The real server is bound to localhost
     for o, a in opts:
@@ -86,39 +88,46 @@ def main():
             print_help()
             return
         else:
-            print 'Unknown option "%s"' % (o, )
+            print('Unknown option "%s"' % (o, ))
             return 1
 
     # Sanitize path and set working directory there (for SimpleHTTPServer)
     serve_directory = os.path.abspath(serve_directory)
     if not os.path.exists(serve_directory):
-        print 'Path "%s" does not exists, can\'t serve from there...' % \
-            (serve_directory, )
+        print('Path "%s" does not exists, can\'t serve from there...' % \
+            (serve_directory, ))
         return 1
     os.chdir(serve_directory)
 
     # Create a new SimpleHTTPServer and serve it from another thread.
     # We create a callback to Twisted to shut it down when we exit.
-    print 'Serving "%s" on %s:%i' % (serve_directory, web_host, web_port)
+    print('Serving "%s" on %s:%i' % (serve_directory, web_host, web_port))
     httpd = SocketServer.TCPServer((web_host, web_port),
                                    SimpleHTTPServer.SimpleHTTPRequestHandler)
     start_httpd(httpd)
-    reactor.addSystemEventTrigger('before', 'shutdown', stop_httpd, httpd=httpd)
+    reactor.addSystemEventTrigger(
+        'before', 'shutdown',
+        stop_httpd, httpd=httpd,
+    )
 
     # Create a directory to hold our hidden service. Twisted will unlink it
     # when we exit.
     hs_temp = tempfile.mkdtemp(prefix='torhiddenservice')
-    reactor.addSystemEventTrigger('before', 'shutdown',
-                                  functools.partial(txtorcon.util.delete_file_or_tree, hs_temp))
+    reactor.addSystemEventTrigger(
+        'before', 'shutdown',
+        functools.partial(txtorcon.util.delete_file_or_tree, hs_temp)
+    )
 
     # Add the hidden service to a blank configuration
     config = txtorcon.TorConfig()
     config.SOCKSPort = 0
     config.ORPort = 9089
-    config.HiddenServices = [txtorcon.HiddenService(config, hs_temp,
-                                                    ['%i %s:%i' % (hs_public_port,
-                                                                   web_host,
-                                                                   web_port)])]
+    config.HiddenServices = [
+        txtorcon.HiddenService(
+            config, hs_temp,
+            ports=['%i %s:%i' % (hs_public_port, web_host, web_port)]
+        )
+    ]
     config.save()
 
     # Now launch tor
