@@ -1,9 +1,10 @@
 import os
 import sys
 import tempfile
+import ipaddress
 from mock import patch
 from unittest import skipIf
-import ipaddress
+from os.path import exists
 
 from twisted.trial import unittest
 from twisted.internet import defer
@@ -14,7 +15,6 @@ from zope.interface import implementer
 from txtorcon.util import process_from_address
 from txtorcon.util import delete_file_or_tree
 from txtorcon.util import find_keywords
-from txtorcon.util import ip_from_int
 from txtorcon.util import find_tor_binary
 from txtorcon.util import maybe_ip_addr
 from txtorcon.util import unescape_quoted_string
@@ -44,12 +44,6 @@ class FakeProtocolFactory:
         return None
 
 
-class TestIPFromInt(unittest.TestCase):
-
-    def test_cast(self):
-        self.assertEqual(ip_from_int(0x7f000001), '127.0.0.1')
-
-
 class TestGeoIpDatabaseLoading(unittest.TestCase):
 
     def test_bad_geoip_path(self):
@@ -70,10 +64,14 @@ class TestGeoIpDatabaseLoading(unittest.TestCase):
 
     @skipIf('pypy' in sys.version.lower(), "No GeoIP in PyPy")
     def test_return_geoip_object(self):
+        # requires a valid GeoIP database to work, so hopefully we're
+        # on Debian or similar...
+        fname = "/usr/share/GeoIP/GeoIP.dat"
+        if not exists(fname):
+            return
+
         from txtorcon import util
-        (fd, f) = tempfile.mkstemp()
-        ret_val = util.create_geoip(f)
-        delete_file_or_tree(f)
+        ret_val = util.create_geoip(fname)
         self.assertEqual(type(ret_val).__name__, 'GeoIP')
 
 
